==> tuia-commercial-center-api-0.0.4-20190711.091300-8-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/commercial/mission/req/MissionVerifyReq.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.commercial.mission.req;

import cn.com.duiba.tuia.commercial.center.api.dto.commercial.CommercialUserReq;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.user.BizActivityUserDto;

import java.io.Serializable;

/**
 * [商业化活动]任务条件检查参数
 *
 * @author zhangbaiqiang
 * @date 2019-03-13
 */
public class MissionVerifyReq implements Serializable {
    private static final long serialVersionUID = 8717150118001394110L;

    /**
     * 用户参数
     */
    private CommercialUserReq userReq;

    /**
     * 活动用户信息
     */
    private BizActivityUserDto activityUserDto;

    /**
     * [种红包]当日种红包次数
     */
    private Integer curPlantTimes;

    /**
     * [种红包]当日收红包次数
     */
    private Integer curPickTimes;

    /**
     * 当日挖矿次数
     *
     * @return
     */
    private Integer curDigTimes;


    /**
     * 连续任务进度
     */
    private Integer curEnterCaveProgess;

    /**
     * 当日打开宝箱个数
     *
     * @return
     */
    private Integer openTreasureBox;

    /*
     * 用户今日增值弹窗任务的状态 0-未开启 1-开启未完成 2-已完成
     * */
    private int vatMissionStatus;

    public int getVatMissionStatus() {
        return vatMissionStatus;
    }

    public MissionVerifyReq setVatMissionStatus(int vatMissionStatus) {
        this.vatMissionStatus = vatMissionStatus;
        return this;
    }

    public CommercialUserReq getUserReq() {
        return userReq;
    }

    public MissionVerifyReq setUserReq(CommercialUserReq userReq) {
        this.userReq = userReq;
        return this;
    }

    public BizActivityUserDto getActivityUserDto() {
        return activityUserDto;
    }

    public MissionVerifyReq setActivityUserDto(BizActivityUserDto activityUserDto) {
        this.activityUserDto = activityUserDto;
        return this;
    }

    public Integer getCurPlantTimes() {
        return curPlantTimes;
    }

    public MissionVerifyReq setCurPlantTimes(Integer curPlantTimes) {
        this.curPlantTimes = curPlantTimes;
        return this;
    }

    public Integer getCurPickTimes() {
        return curPickTimes;
    }

    public MissionVerifyReq setCurPickTimes(Integer curPickTimes) {
        this.curPickTimes = curPickTimes;
        return this;
    }

    public Integer getCurDigTimes() {
        return curDigTimes;
    }

    public MissionVerifyReq setCurDigTimes(Integer curDigTimes) {
        this.curDigTimes = curDigTimes;
        return this;
    }

    public Integer getOpenTreasureBox() {
        return openTreasureBox;
    }

    public MissionVerifyReq setOpenTreasureBox(Integer openTreasureBox) {
        this.openTreasureBox = openTreasureBox;
        return this;
    }

    public Integer getCurEnterCaveProgess() {
        return curEnterCaveProgess;
    }

    public MissionVerifyReq setCurEnterCaveProgess(Integer curEnterCaveProgess) {
        this.curEnterCaveProgess = curEnterCaveProgess;
        return this;
    }
}

==> tuia-commercial-center-api-1.0.3-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/commercial/mission/req/MissionVerifyReq.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.commercial.mission.req;

import cn.com.duiba.tuia.commercial.center.api.dto.commercial.user.req.CommercialUserReq;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.user.BizActivityUserDto;

import java.io.Serializable;

/**
 * [商业化活动]任务条件检查参数
 *
 * @author zhangbaiqiang
 * @date 2019-03-13
 */
public class MissionVerifyReq implements Serializable {
    private static final long serialVersionUID = 8717150118001394110L;

    /**
     * 用户参数
     */
    private CommercialUserReq userReq;

    /**
     * 活动用户信息
     */
    private BizActivityUserDto activityUserDto;

    /**
     * [种红包]当日种红包次数
     */
    private Integer curPlantTimes;

    /**
     * [种红包]当日收红包次数
     */
    private Integer curPickTimes;

    /**
     * 当日挖矿次数
     *
     * @return
     */
    private Integer curDigTimes;


    /**
     * 连续任务进度
     */
    private Integer curEnterCaveProgess;

    /**
     * 当日打开宝箱个数
     *
     * @return
     */
    private Integer openTreasureBox;

    /*
     * 用户今日增值弹窗任务的状态 0-未开启 1-开启未完成 2-已完成
     * */
    private int vatMissionStatus;

    public int getVatMissionStatus() {
        return vatMissionStatus;
    }

    public MissionVerifyReq setVatMissionStatus(int vatMissionStatus) {
        this.vatMissionStatus = vatMissionStatus;
        return this;
    }

    public CommercialUserReq getUserReq() {
        return userReq;
    }

    public MissionVerifyReq setUserReq(CommercialUserReq userReq) {
        this.userReq = userReq;
        return this;
    }

    public BizActivityUserDto getActivityUserDto() {
        return activityUserDto;
    }

    public MissionVerifyReq setActivityUserDto(BizActivityUserDto activityUserDto) {
        this.activityUserDto = activityUserDto;
        return this;
    }

    public Integer getCurPlantTimes() {
        return curPlantTimes;
    }

    public MissionVerifyReq setCurPlantTimes(Integer curPlantTimes) {
        this.curPlantTimes = curPlantTimes;
        return this;
    }

    public Integer getCurPickTimes() {
        return curPickTimes;
    }

    public MissionVerifyReq setCurPickTimes(Integer curPickTimes) {
        this.curPickTimes = curPickTimes;
        return this;
    }

    public Integer getCurDigTimes() {
        return curDigTimes;
    }

    public MissionVerifyReq setCurDigTimes(Integer curDigTimes) {
        this.curDigTimes = curDigTimes;
        return this;
    }

    public Integer getOpenTreasureBox() {
        return openTreasureBox;
    }

    public MissionVerifyReq setOpenTreasureBox(Integer openTreasureBox) {
        this.openTreasureBox = openTreasureBox;
        return this;
    }

    public Integer getCurEnterCaveProgess() {
        return curEnterCaveProgess;
    }

    public MissionVerifyReq setCurEnterCaveProgess(Integer curEnterCaveProgess) {
        this.curEnterCaveProgess = curEnterCaveProgess;
        return this;
    }
}
